@@ -124,6 +124,12 @@ fn command() -> Command {
                 .value_parser(["bash", "zsh", "powershell", "fish", "elvish"])
                 .ignore_case(true)
                 .help("Print completion script for SHELL to stdout"),
+        )
+        .arg(
+            Arg::new("generate-man-page")
+                .long("generate-man-page")
+                .action(ArgAction::SetTrue)
+                .help("Print man page to stdout"),
         );
 
     #[cfg(feature = "bat-printer")]
@@ -157,7 +163,8 @@ fn command() -> Command {
                 "hgrep is grep with human-friendly search output. It eats an output of `grep -nH` and prints the \
                 matches with syntax-highlighted code snippets.\n\n\
                 $ grep -nH pattern -R . | hgrep\n\n\
-                hgrep has its builtin grep implementation. It's subset of ripgrep and faster when many matches are found.\n\n\
+                hgrep has its builtin subset of ripgrep. Its search output and performance are better than reading \
+                `grep -nH`.\n\n\
                 $ hgrep pattern\n\n\
                 For more details, visit https://github.com/rhysd/hgrep"
             )
@@ -468,11 +475,19 @@ enum PrinterKind {
 
 fn app() -> Result<bool> {
     let matches = command().get_matches();
+
     if let Some(shell) = matches.get_one::<String>("generate-completion-script") {
         generate_completion_script(shell);
         return Ok(true);
     }
 
+    if matches.get_flag("generate-man-page") {
+        let man = clap_mangen::Man::new(command());
+        let stdout = io::stdout();
+        man.render(&mut stdout.lock())?;
+        return Ok(true);
+    }
+
     #[allow(unused_variables)] // printer_kind is unused when syntect-printer is disabled for now
     let printer_kind = match matches.get_one::<String>("printer").unwrap().as_str() {
         #[cfg(feature = "bat-printer")]
@@ -483,7 +498,7 @@ fn app() -> Result<bool> {
         "syntect" => PrinterKind::Syntect,
         #[cfg(not(feature = "syntect-printer"))]
         "syntect" => anyhow::bail!("--printer syntect is not available because 'syntect-printer' feature was disabled at compilation"),
-        p => anyhow::bail!("Unknown printer '{}', at --printer option. It must be one of 'bat' or 'syntect'", p),
+        p => anyhow::bail!("Unknown printer '{}' at --printer option. It must be one of 'bat' or 'syntect'", p),
     };
 
     let min_context = matches
@@ -651,10 +666,7 @@ fn app() -> Result<bool> {
     if printer_kind == PrinterKind::Bat {
         let mut found = false;
         let printer = BatPrinter::new(printer_opts);
-        // XXX: io::stdin().lock() is not available since bat's implementation internally takes lock of stdin
-        // *even if* it does not use stdin.
-        // https://github.com/sharkdp/bat/issues/1902
-        for f in io::BufReader::new(io::stdin())
+        for f in io::BufReader::new(io::stdin().lock())
             .grep_lines()
             .chunks_per_file(min_context, max_context)
         {
@@ -669,8 +681,12 @@ fn app() -> Result<bool> {
 
 fn main() {
     #[cfg(windows)]
-    {
-        ansi_term::enable_ansi_support().unwrap();
+    if let Err(code) = ansi_term::enable_ansi_support() {
+        eprintln!(
+            "ANSI color support could not be enabled with error code {}",
+            code
+        );
+        process::exit(2);
     }
 
     let status = match app() {
@@ -684,6 +700,7 @@ fn main() {
             2
         }
     };
+
     process::exit(status);
 }
 
